@@ -5,14 +5,14 @@ describe WebMock::ResponseFactory do
   describe "response_for" do
 
     it "should create response with options passed as arguments" do
-      options = {:body => "abc", :headers => {:a => :b}}
+      options = {body: "abc", headers: {a: :b}}
       expect(WebMock::Response).to receive(:new).with(options).and_return(@response = double(WebMock::Response))
       expect(WebMock::ResponseFactory.response_for(options)).to eq(@response)
     end
 
 
     it "should create dynamic response for argument responding to call" do
-      callable = double(:call => {:body => "abc"})
+      callable = double(call: {body: "abc"})
       expect(WebMock::DynamicResponse).to receive(:new).with(callable).and_return(@response = double(WebMock::Response))
       expect(WebMock::ResponseFactory.response_for(callable)).to eq(@response)
     end
@@ -23,16 +23,16 @@ end
 
 describe WebMock::Response do
   before(:each) do
-    @response = WebMock::Response.new(:headers => {'A' => 'a'})
+    @response = WebMock::Response.new(headers: {'A' => 'a'})
   end
 
   it "should raise an error when initialized with unknown option" do
-    expect { WebMock::Response.new(:foo => "bar") }.to raise_error('Unknown key: "foo". Valid keys are: "headers", "status", "body", "exception", "should_timeout"')
+    expect { WebMock::Response.new(foo: "bar") }.to raise_error('Unknown key: "foo". Valid keys are: "headers", "status", "body", "exception", "should_timeout"')
   end
 
   it "should report normalized headers" do
     expect(WebMock::Util::Headers).to receive(:normalize_headers).with('A' => 'a').and_return('B' => 'b')
-    @response = WebMock::Response.new(:headers => {'A' => 'a'})
+    @response = WebMock::Response.new(headers: {'A' => 'a'})
     expect(@response.headers).to eq({'B' => 'b'})
   end
 
@@ -42,12 +42,12 @@ describe WebMock::Response do
     end
 
     it "should return assigned status" do
-      @response = WebMock::Response.new(:status => 500)
+      @response = WebMock::Response.new(status: 500)
       expect(@response.status).to eq([500, ""])
     end
 
     it "should return assigned message" do
-      @response = WebMock::Response.new(:status => [500, "Internal Server Error"])
+      @response = WebMock::Response.new(status: [500, "Internal Server Error"])
       expect(@response.status).to eq([500, "Internal Server Error"])
     end
   end
@@ -55,21 +55,21 @@ describe WebMock::Response do
   describe "raising error" do
 
     it "should raise error if any assigned" do
-      @response = WebMock::Response.new(:exception => ArgumentError)
+      @response = WebMock::Response.new(exception: ArgumentError)
       expect {
         @response.raise_error_if_any
       }.to raise_error(ArgumentError, "Exception from WebMock")
     end
 
     it "should raise error if any assigned as instance" do
-      @response = WebMock::Response.new(:exception => ArgumentError.new("hello world"))
+      @response = WebMock::Response.new(exception: ArgumentError.new("hello world"))
       expect {
         @response.raise_error_if_any
       }.to raise_error(ArgumentError, "hello world")
     end
 
     it "should raise error if any assigned as string" do
-      @response = WebMock::Response.new(:exception => "hello world")
+      @response = WebMock::Response.new(exception: "hello world")
       expect {
         @response.raise_error_if_any
       }.to raise_error("hello world")
@@ -84,7 +84,7 @@ describe WebMock::Response do
   describe "timeout" do
 
     it "should know if it should timeout" do
-      @response = WebMock::Response.new(:should_timeout => true)
+      @response = WebMock::Response.new(should_timeout: true)
       expect(@response.should_timeout).to be_truthy
     end
 
@@ -102,28 +102,28 @@ describe WebMock::Response do
     end
 
     it "should report body if assigned" do
-      @response = WebMock::Response.new(:body => "abc")
+      @response = WebMock::Response.new(body: "abc")
       expect(@response.body).to eq("abc")
     end
 
     it "should report string even if existing file path was provided" do
-      @response = WebMock::Response.new(:body => __FILE__)
+      @response = WebMock::Response.new(body: __FILE__)
       expect(@response.body).to eq(__FILE__)
     end
 
     it "should report content of a IO object if provided" do
-      @response = WebMock::Response.new(:body => File.new(__FILE__))
+      @response = WebMock::Response.new(body: File.new(__FILE__))
       expect(@response.body).to eq(File.read(__FILE__))
     end
 
     it "should report many times content of a IO object if provided" do
-      @response = WebMock::Response.new(:body => File.new(__FILE__))
+      @response = WebMock::Response.new(body: File.new(__FILE__))
       expect(@response.body).to eq(File.read(__FILE__))
       expect(@response.body).to eq(File.read(__FILE__))
     end
 
     it "should work with Pathnames" do
-      @response = WebMock::Response.new(:body => Pathname.new(__FILE__))
+      @response = WebMock::Response.new(body: Pathname.new(__FILE__))
       expect(@response.body).to eq(File.read(__FILE__))
     end
 
@@ -131,7 +131,7 @@ describe WebMock::Response do
     # body to return a hash, to prevent this:
     #
     it "should error if not given one of the allowed types" do
-      expect { WebMock::Response.new(:body => Hash.new) }.to \
+      expect { WebMock::Response.new(body: Hash.new) }.to \
         raise_error(WebMock::Response::InvalidBody)
     end
 
@@ -205,21 +205,21 @@ describe WebMock::Response do
     describe "with dynamically evaluated options" do
 
       before(:each) do
-        @request_signature = WebMock::RequestSignature.new(:post, "www.example.com", :body => "abc", :headers => {'A' => 'a'})
+        @request_signature = WebMock::RequestSignature.new(:post, "www.example.com", body: "abc", headers: {'A' => 'a'})
       end
 
       it "should have evaluated body" do
-        @response = WebMock::Response.new(:body => lambda {|request| request.body})
+        @response = WebMock::Response.new(body: lambda {|request| request.body})
         expect(@response.evaluate(@request_signature).body).to eq("abc")
       end
 
       it "should have evaluated headers" do
-        @response = WebMock::Response.new(:headers => lambda {|request| request.headers})
+        @response = WebMock::Response.new(headers: lambda {|request| request.headers})
         expect(@response.evaluate(@request_signature).headers).to eq({'A' => 'a'})
       end
 
       it "should have evaluated status" do
-        @response = WebMock::Response.new(:status => lambda {|request| 302})
+        @response = WebMock::Response.new(status: lambda {|request| 302})
         expect(@response.evaluate(@request_signature).status).to eq([302, ""])
       end
 
@@ -232,12 +232,12 @@ describe WebMock::Response do
     describe "evaluating response options" do
 
       it "should evaluate new response with evaluated options" do
-        request_signature = WebMock::RequestSignature.new(:post, "www.example.com", :body => "abc", :headers => {'A' => 'a'})
+        request_signature = WebMock::RequestSignature.new(:post, "www.example.com", body: "abc", headers: {'A' => 'a'})
         response = WebMock::DynamicResponse.new(lambda {|request|
           {
-            :body => request.body,
-            :headers => request.headers,
-            :status => 302
+            body: request.body,
+            headers: request.headers,
+            status: 302
           }
         })
         evaluated_response = response.evaluate(request_signature)
@@ -247,10 +247,10 @@ describe WebMock::Response do
       end
 
       it "should be equal to static response after evaluation" do
-        request_signature = WebMock::RequestSignature.new(:post, "www.example.com", :body => "abc")
-        response = WebMock::DynamicResponse.new(lambda {|request| {:body => request.body}})
+        request_signature = WebMock::RequestSignature.new(:post, "www.example.com", body: "abc")
+        response = WebMock::DynamicResponse.new(lambda {|request| {body: request.body}})
         evaluated_response = response.evaluate(request_signature)
-        expect(evaluated_response).to eq(WebMock::Response.new(:body => "abc"))
+        expect(evaluated_response).to eq(WebMock::Response.new(body: "abc"))
       end
 
       describe "when raw response is evaluated" do
